/*
 * ShowTokenInfo.java - Show token info message
 * Copyright (C) 1999 Slava Pestov
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.gjt.sp.jedit.msg;

import org.gjt.sp.jedit.*;

/**
 * Message to display documentation for the specified language token.
 * @author Slava Pestov
 * @version EditBus release 9
 */
public class ShowTokenInfo extends EBMessage
{
	/**
	 * Creates a new token information message.
	 * @param source The message source
	 * @param view The view
	 * @param language The programming language. This should be the
	 * name of a jEdit edit mode. The sender should probably set this
	 * to view.getBuffer().getMode().getName(), and the receiver should
	 * check if it understands this language (for example, JIndex
	 * should only handle messages with the language set to "java").
	 * @param token The token. This must be a fully qualified
	 * method, function or class name
	 */
	public ShowTokenInfo(EBComponent source, View view,
		String language, String token)
	{
		super(source);
		if(language == null || token == null)
			throw new NullPointerException("Language and token"
				+ " must be non-null");

		this.view = view;
		this.language = language;
		this.token = token;
	}

	/**
	 * Returns the view.
	 */
	public View getView()
	{
		return view;
	}

	/**
	 * Returns the language. This must be the name of a valid jEdit
	 * edit mode.
	 */
	public String getLanguage()
	{
		return language;
	}

	/**
	 * Returns the token to look up. This must be a valid method, class
	 * or function name in the specified language.
	 */
	public String getToken()
	{
		return token;
	}

	public String paramString()
	{
		return super.paramString() + ",view=" + view + ",language="
			+ language + ",token=" + token;
	}

	// private members
	private View view;
	private String language;
	private String token;
}
