/*
 * ViewURL.java - Displays a URL in a web browser
 * Copyright (C) 1999 Slava Pestov
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.gjt.sp.jedit.msg;

import java.net.URL;
import org.gjt.sp.jedit.*;

/**
 * Message to display the specified URL in a WWW browser or previewer.
 * It can be used to display documentation, or preview files, etc.
 * @author Slava Pestov
 * @version EditBus release 9
 */
public class ViewURL extends EBMessage
{
	/**
	 * Creates a new URL view message.
	 * @param source The message source
	 * @param view The view
	 * @param url The URL. If null, an empty browser window should be
	 * displayed
	 */
	public ViewURL(EBComponent source, View view, URL url)
	{
		super(source);

		this.view = view;
		this.url = url;
	}

	/**
	 * Returns the view.
	 */
	public View getView()
	{
		return view;
	}

	/**
	 * Returns the URL.
	 */
	public URL getURL()
	{
		return url;
	}

	public String paramString()
	{
		return super.paramString() + ",view=" + view + ",url=" + url;
	}

	// private members
	private View view;
	private URL url;
}
